RawDumpCommand

Struct RawDumpCommand 

pub struct RawDumpCommand {
Show 29 fields pub tail: Option<usize>, pub filter: Vec<String>, pub moniker: Vec<String>, pub component: Vec<String>, pub exclude: Vec<String>, pub exclude_regex: Vec<String>, pub exclude_regex_file: Option<String>, pub tag: Vec<String>, pub exclude_tags: Vec<String>, pub severity: Option<Severity>, pub kernel: bool, pub since: Option<DetailedDateTime>, pub since_boot: Option<Duration>, pub until: Option<DetailedDateTime>, pub until_boot: Option<Duration>, pub hide_tags: bool, pub hide_file: bool, pub no_color: bool, pub case_sensitive: bool, pub show_metadata: bool, pub show_full_moniker: bool, pub prefer_url_component_name: bool, pub hide_moniker: bool, pub clock: Option<TimeFormat>, pub pid: Option<u64>, pub tid: Option<u64>, pub force_set_severity: bool, pub encoding: Option<LogEncoding>, pub json: bool,
}
Dumps all logs from a given target’s session.

Fields

tail: Option<usize>

return only the last N log lines.

filter: Vec<String>

filter for a string in either the message, component or url. May be repeated.

moniker: Vec<String>

DEPRECATED: use –component

component: Vec<String>

fuzzy search for a component by moniker or url. May be repeated.

exclude: Vec<String>

exclude a string in either the message, component or url. May be repeated.

exclude_regex: Vec<String>

exclude logs matching a regular expression. May be repeated.

exclude_regex_file: Option<String>

path to a file containing regular expressions, one per line, to exclude.

tag: Vec<String>

filter for only logs with a given tag. May be repeated.

exclude_tags: Vec<String>

exclude logs with a given tag. May be repeated.

severity: Option<Severity>

set the minimum severity. Accepted values (from lower to higher) are: trace, debug, info, warn (or warning), error, fatal. This field is case insensitive.

kernel: bool

outputs only kernel logs, unless combined with –component.

since: Option<DetailedDateTime>

show only logs after a certain time (exclusive)

since_boot: Option<Duration>

show only logs after a certain time (as a boot timestamp: seconds from the target’s boot time).

until: Option<DetailedDateTime>

show only logs until a certain time (exclusive)

until_boot: Option<Duration>

show only logs until a certain time (as a boot timestamp: seconds since the target’s boot time).

hide_tags: bool

hide the tag field from output (does not exclude any log messages)

hide_file: bool

hide the file and line number field from output (does not exclude any log messages)

no_color: bool

disable coloring logs according to severity. Note that you can permanently disable this with ffx config set log_cmd.color false

case_sensitive: bool

if enabled, text filtering options are case-sensitive this applies to –filter, –exclude, –tag, and –exclude-tags.

show_metadata: bool

shows process-id and thread-id in log output

show_full_moniker: bool

shows the full moniker in log output. By default this is false and only the last segment of the moniker is printed.

prefer_url_component_name: bool

if enabled, prefer using the component URL for the component name over the moniker.

hide_moniker: bool

hide the moniker field from output (does not exclude any log messages)

clock: Option<TimeFormat>

how to display log timestamps. Options are “utc”, “local”, or “boot” (i.e. nanos since target boot). Default is boot.

pid: Option<u64>

filters by pid

tid: Option<u64>

filters by tid

force_set_severity: bool

if enabled, selectors will be passed directly to Archivist without any filtering. If disabled and no matching components are found, the user will be prompted to either enable this or be given a list of selectors to choose from. This applies to both –set-severity and the set-severity subcommand.

encoding: Option<LogEncoding>

EXPERIMENTAL/SUBJECT TO REMOVAL: select the encoding used to retrieve logs from the archivist. Options are “json” or “fxt”. Default is “json”.

json: bool

enables structured JSON logs.

Implementations