pub trait BootTimeAccessor {
// Required methods
fn set_boot_timestamp(&mut self, _boot_ts_nanos: Timestamp);
fn get_boot_timestamp(&self) -> Timestamp;
}Required Methods
Sourcefn set_boot_timestamp(&mut self, _boot_ts_nanos: Timestamp)
fn set_boot_timestamp(&mut self, _boot_ts_nanos: Timestamp)
Sets the boot timestamp in nanoseconds since the Unix epoch.
Sourcefn get_boot_timestamp(&self) -> Timestamp
fn get_boot_timestamp(&self) -> Timestamp
Returns the boot timestamp in nanoseconds since the Unix epoch.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".